%define rcnum   rc1
%define rel     14

%bcond_without compat
%{!?lua_compat_version: %global lua_compat_version 5.1}
%{!?lua_compat_libdir: %global lua_compat_libdir %{_libdir}/lua/%{lua_compat_version}}
%{!?lua_compat_pkgdir: %global lua_compat_pkgdir %{_datadir}/lua/%{lua_compat_version}}
%{!?lua_compat_builddir: %global lua_compat_builddir %{_builddir}/lua%{lua_compat_version}-%{name}-%{version}-%{release}}

Summary:        Network access library for the Lua programming language
Name:           lua-socket
Version:        3.0
Release:        %mkrel -c %{rcnum} %{rel}
License:        MIT
Group:          Development/Other
URL:            http://www.impa.br/~diego/software/luasocket
Source0:        https://github.com/diegonehab/luasocket/archive/v%{version}-%{rcnum}.tar.gz

Patch1:         luasocket-3.0-settimeout.patch

# All changes in the upstream repo from %{baseversion} tag to the
# current master.
Patch10:        luasocket-no-global-vars.patch
# Fix for lua 5.3
Patch11:	luasocket-3.0-checkint.patch

BuildRequires:  pkgconfig(lua)
Requires:       lua%{lua_version}

%description
LuaSocket is a Lua extension library that is composed by two parts: a
C layer that provides support for the TCP and UDP transport layers,
and a set of Lua modules that add support for the SMTP (sending
e-mails), HTTP (WWW access) and FTP (uploading and downloading files)
protocols.

%if %{with compat}
%package -n lua%{lua_compat_version}-socket
Summary:        Network support for the Lua %{lua_compat_version} language
Obsoletes:      lua-socket%{lua_compat_version} < 3.0-0.rc1.11
Provides:       lua-socket%{lua_compat_version} = %{version}-%{release}
Requires:       lua(abi) = %{lua_compat_version}
Requires:       lua%{lua_compat_version}
BuildRequires:  lua%{lua_compat_version}-devel

%description -n lua%{lua_compat_version}-socket
LuaSocket is a Lua %{lua_compat_version} extension library that is composed by two parts: The
C core that provides support for the TCP and UDP transport layers, and the
set of Lua %{lua_compat_version} modules that add support for functionality commonly needed by
applications that deal with the Internet.

Among the support modules, the most commonly used implement the SMTP, HTTP
and FTP. In addition there are modules for MIME, URL handling and LTN12.
%endif

%prep
%setup -n luasocket-%{version}-%{rcnum}
%patch1 -p1
%patch11 -p1

%if %{with compat}
rm -rf %{lua_compat_builddir}
cp -a . %{lua_compat_builddir}
%endif

%patch10 -p1

%build
%set_build_flags
%make_build linux \
  LUAV=%{lua_version} \
  OPTFLAGS="%{optflags} -fPIC -DLUA_COMPAT_APIINTCASTS"

%if %{with compat}
pushd %{lua_compat_builddir}
%make_build linux \
  LUAV=%{lua_compat_version} \
  LUAINC_linux=%{_includedir}/lua-%{lua_compat_version} \
  OPTFLAGS="%{optflags} -fPIC"
popd
%endif

%install
%set_build_flags
make install-unix OPTFLAGS="%{optflags}" INSTALL_TOP=%{buildroot} \
    INSTALL_TOP_CDIR=%{buildroot}%{lua_libdir} \
    INSTALL_TOP_LDIR=%{buildroot}%{lua_pkgdir}

%if %{with compat}
pushd %{lua_compat_builddir}
make install-unix OPTFLAGS="%{optflags}" INSTALL_TOP=%{buildroot} \
    INSTALL_TOP_CDIR=%{buildroot}%{lua_compat_libdir} \
    INSTALL_TOP_LDIR=%{buildroot}%{lua_compat_pkgdir}
popd
%endif

%files
%doc NEW README doc/*
%{lua_libdir}/mime/
%{lua_libdir}/socket/
%{lua_pkgdir}/*.lua
%{lua_pkgdir}/socket/

%if %{with compat}
%files -n lua%{lua_compat_version}-socket
%license LICENSE
%doc NEW README doc/*
%{lua_compat_libdir}/mime/
%{lua_compat_libdir}/socket/
%{lua_compat_pkgdir}/*.lua
%{lua_compat_pkgdir}/socket/
%endif


%changelog
* Fri Mar 18 2022 umeabot <umeabot> 3.0-0.rc1.14.mga9
+ Revision: 1797947
- Mageia 9 Mass Rebuild

* Fri Apr 02 2021 wally <wally> 3.0-0.rc1.13.mga9
+ Revision: 1712831
- rebuild for lua 5.4

* Tue Mar 30 2021 wally <wally> 3.0-0.rc1.12.mga9
+ Revision: 1711993
- restore compat pkg lua5.1-socket

* Mon Mar 29 2021 wally <wally> 3.0-0.rc1.11.mga9
+ Revision: 1711755
- build with latest lua
- drop unused lua-socket5.1

* Mon Aug 31 2020 martinw <martinw> 3.0-0.rc1.10.mga8
+ Revision: 1620514
- fix "undefined symbol: luaL_checkint" error when loading /usr/lib64/lua/5.3/socket/core.so

* Fri Apr 17 2020 ovitters <ovitters> 3.0-0.rc1.9.mga8
+ Revision: 1568333
- add patch from Fedora
- add patch from upstream
- build against Lua 5.3 (using Fedora spec as inspiration)

* Thu Feb 13 2020 umeabot <umeabot> 3.0-0.rc1.8.mga8
+ Revision: 1514902
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Sep 23 2018 umeabot <umeabot> 3.0-0.rc1.7.mga7
+ Revision: 1299377
- Mageia 7 Mass Rebuild

* Sun Jun 24 2018 pterjan <pterjan> 3.0-0.rc1.6.mga7
+ Revision: 1239290
- Build against lua 5.2

* Sun Jun 24 2018 pterjan <pterjan> 3.0-0.rc1.5.mga7
+ Revision: 1239284
- Fix more breakages with lua 5.3

* Sun Jun 24 2018 pterjan <pterjan> 3.0-0.rc1.4.mga7
+ Revision: 1239280
- Fix missing symbol with lua 5.3
+ kekepower <kekepower>
- Use make_build

* Fri Mar 04 2016 luigiwalser <luigiwalser> 3.0-0.rc1.3.mga6
+ Revision: 985780
- fix invalid usage of rel macro
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
- Mageia 6 Mass Rebuild
- Mageia 6 Mass Rebuild
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 akien <akien> 3.0-0.rc1.2.mga5
+ Revision: 661582
- Fix requires of lua5.1 package

* Sun Aug 10 2014 akien <akien> 3.0-0.rc1.1.mga5
+ Revision: 661548
- Version 3.0 rc1
- Use "make install-both-unix" to provide both Lua 5.2 and 5.1 builds

* Fri Oct 18 2013 umeabot <umeabot> 2.0.2-8.mga4
+ Revision: 507593
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.0.2-7.mga3
+ Revision: 359071
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 pterjan <pterjan> 2.0.2-6.mga3
+ Revision: 334419
- Force Lua 5.1

* Sun Mar 13 2011 shikamaru <shikamaru> 2.0.2-5.mga1
+ Revision: 70270
- imported package lua-socket


* Sat Mar 12 2011 Rémy Clouard <shikamaru@mandriva.org> 2.0.2-5.mga1
- clean spec (buildroot)
- retab
- reorder tags
- remove unneeded obsoletes (2008.1)

* Wed Dec 08 2010 Rémy Clouard <shikamaru@mandriva.org> 2.0.2-4mdv2011.0
+ Revision: 616183
- rebuild for the mass rebuild

* Wed Sep 23 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.0.2-3mdv2010.0
+ Revision: 448047
- bump release
- package renaming
- package renaming

* Fri Sep 04 2009 Thierry Vignaud <tv@mandriva.org> 2.0.2-2mdv2010.0
+ Revision: 429883
- rebuild

* Thu Aug 28 2008 Adam Williamson <awilliamson@mandriva.org> 2.0.2-1mdv2009.0
+ Revision: 277052
- package doc files properly with %%doc
- drop now unnecessary %%post and %%postun workarounds
- drop the manual installation, just pass appropriate vars to makeinstall
- rewrap description
- obsolete the insane old packaging of this as if it were a system library
- correct lua buildrequires and requires
- add new cflags.patch for just the allowing external CFLAGS bit
- drop old patch (lots of irrelevant stuff in it)
- update URL
- rebuild for new lua
- drop unnecessary defines
- new release 2.0.2

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request
    - import luasocket

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


